Get the start and end coordinates of a spatial object's axis
data_get_axis_start_end.RdThis function takes a spatial object with a LINESTRING geometry and returns a data frame containing the start and end coordinates of the axis.
Value
A data frame with two rows, where the first row contains the start coordinates (x and y) and the second row contains the end coordinates (x and y).
Examples
df <- data_get_axis_start_end(line_sf)
#> Error in (function (cond) .Internal(C_tryCatchHelper(addr, 1L, cond)))(structure(list(message = "argument \"con\" is missing, with no default", call = data_get_axis_start_end(line_sf)), class = c("getvarError", "missingArgError", "error", "condition"))): error in evaluating the argument 'conn' in selecting a method for function 'sqlInterpolate': argument "con" is missing, with no default